Grid exploration
================

ExploreGridProfilesOrdinal
--------------------------
.. autoclass:: poisson_approval.ExploreGridProfilesOrdinal
    :members:

ExploreGridTaus
---------------
.. autoclass:: poisson_approval.ExploreGridTaus
    :members:
